@@ -9,8 +9,7 @@ information.
 """
 __all__ = []
 
-import inspect, myghty.exception, sys
-
+import myghty.exception, sys
 from paste.evalexception.middleware import *
 from paste.exceptions.formatter import *
 
@@ -104,7 +103,7 @@ class HTMLFormatter(formatter.HTMLFormatter):
         for (importance, name), value in general_data.items():
             data_by_importance[importance].append(
                 (name, value))
-        for value in data_by_importance.values():
+        for value in data_by_importance.itervalues():
             value.sort()
         return self.format_combine(data_by_importance, lines, exc_info)
         
@@ -198,7 +197,7 @@ def format_html(exc_data, include_hidden_frames=False, **ops):
     </div>
     """ % (short_er, long_er, cgi.escape(text_er)), ''
 
-error_template = '''
+error_template = '''\
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
 <head>
@@ -271,15 +270,21 @@ error_template = '''
 
 class InvalidTemplate(Exception):
     pass
+
 from pylons.util import get_prefix
+
 class PylonsEvalException(EvalException):
 
-    def __init__(self, application, global_conf=None, xmlhttp_key=None, error_template=error_template, **errorparams):
+    def __init__(self, application, global_conf=None, xmlhttp_key=None,
+                 error_template=error_template, **errorparams):
         self.application = application
         self.error_template=error_template
         self.debug_infos = {}
         if xmlhttp_key is None:
-            xmlhttp_key = global_conf.get('xmlhttp_key', '_')
+            if global_conf is None:
+                xmlhttp_key = '_'
+            else:
+                xmlhttp_key = global_conf.get('xmlhttp_key', '_')
         self.xmlhttp_key = xmlhttp_key
         self.errorparams = errorparams
         self.errorparams['debug_mode'] = self.errorparams['debug']
@@ -296,10 +301,11 @@ class PylonsEvalException(EvalException):
                 'set_tab':'',
                 'prefix':''}
         except:
-            raise Exception('Invalid template. Please ensure all % signs are properly quoted as %% and no extra substitution strings are present.')
+            raise Exception('Invalid template. Please ensure all % signs are properly '
+                            'quoted as %% and no extra substitution strings are present.')
             
     def eval_javascript(self, base_path, counter):
-        base_path = '/_debug' # Note the difference!
+        base_path += '/_debug' # Note the difference!
         return (
             '<script type="text/javascript" src="%s/mochikit/MochiKit.js">'
             '</script>\n'
@@ -318,6 +324,8 @@ class PylonsEvalException(EvalException):
     #~ pylons.exposed = True
     
     def respond(self, environ, start_response):
+        if environ.get('paste.throw_errors'):
+            return self.application(environ, start_response)
         base_path = request.construct_url(environ, with_path_info=False,
                                           with_query_string=False)
         environ['paste.throw_errors'] = True
@@ -332,13 +340,17 @@ class PylonsEvalException(EvalException):
         try:
             __traceback_supplement__ = Supplement, self, environ
             app_iter = self.application(environ, detect_start_response)
-            return self.catching_iter(app_iter, environ)
+            try:
+                return_iter = list(app_iter)
+                return return_iter
+            finally:
+                if hasattr(app_iter, 'close'):
+                    app_iter.close()
         except:
             exc_info = sys.exc_info()
-            if inspect.isclass(exc_info[0]):
-                for expected in environ.get('paste.expected_exceptions', []):
-                    if issubclass(exc_info[0], expected):
-                        raise
+            for expected in environ.get('paste.expected_exceptions', []):
+                if isinstance(exc_info[1], expected):
+                    raise
                     
             count = debug_counter.next()
             view_uri = self.make_view_url(environ, base_path, count)
@@ -363,7 +375,7 @@ class PylonsEvalException(EvalException):
                     html = formatter.format_html(
                         exc_data, include_hidden_frames=False,
                         include_reusable=False, show_extra_data=False)
-                    return [html]            
+                    return [html]
             
             base_path = get_prefix(environ)
             #base_path = environ['SCRIPT_NAME']
